@@ -11,7 +11,7 @@ use Raisin::Response;
 use Raisin::Routes;
 use Raisin::Util;
 
-our $VERSION = '0.59';
+our $VERSION = '0.60';
 
 sub new {
     my ($class, %args) = @_;
@@ -89,9 +89,42 @@ sub run {
     # load fallback logger (Raisin::Logger)
     $self->load_plugin('Logger', fallback => 1);
 
+    $self->generate_options_routes;
+
     return $psgi;
 }
 
+sub generate_options_routes {
+    my $self = shift;
+
+    my %general_methods;
+
+    # `options` for each `path`
+    for my $path (keys %{ $self->routes->list }) {
+        my @methods = keys %{ $self->routes->list->{$path} };
+        $general_methods{$_}++ for @methods;
+
+        $self->add_route(
+            method => 'OPTIONS',
+            path => $path,
+            code => sub {
+                $self->res->headers([Allow => join(', ', sort @methods)]);
+                undef;
+            },
+        );
+    }
+
+    # all methods which server supports
+    $self->add_route(
+        method => 'OPTIONS',
+        path => '/',
+        code => sub {
+            $self->res->headers([Allow => join(', ', sort keys %general_methods)]);
+            undef;
+        },
+    );
+}
+
 sub psgi {
     my ($self, $env) = @_;
 
@@ -571,6 +604,12 @@ Returns L<Hash::MultiValue> object.
     say param('key'); # -> value
     say param(); # -> { key => 'value', foo => 'bar' }
 
+=head3 include_missing
+
+Returns all declared parameters even if there is no value for a param.
+
+See L<Raisin/Declared-parameters>.
+
 =head3 session
 
 Returns C<psgix.session> hash. When it exists, you can retrieve and store
@@ -1005,8 +1044,6 @@ Shows an example of complex application.
 
 =over
 
-=item * OPTIONS/Allow support;
-
 =item * C<param> doesn't work as expected;
 
 =item * Support for hypermedia (L<HAL|http://stateless.co/hal_specification.html>, L<Link headers|http://www.w3.org/wiki/LinkHeader>);
