@@ -85,10 +85,10 @@ sub add {
         );
     push @{ $self->{routes} }, $ep;
 
-    if ($self->list->{$method}{$path}) {
-        carp "Route `$path` via `$method` is redefined";
+    if ($self->list->{$path}{$method}) {
+        print STDERR "Route redefined: `$method` `$path`\n";
     }
-    $self->list->{$method}{$path} = scalar @{ $self->{routes} };
+    $self->list->{$path}{$method} = scalar @{ $self->{routes} };
 }
 
 sub find {
