@@ -15,6 +15,7 @@ has 'named';
 has 'params' => [];
 has 'path';
 has 'regex';
+has 'summary';
 
 sub new {
     my ($class, %args) = @_;
@@ -77,6 +78,16 @@ sub _rep_regex {
     return $char . $r;
 }
 
+sub tags {
+    my $self = shift;
+
+    unless (scalar @{ $self->{tags} || [] }) {
+        return [Raisin::Util::make_tag_from_path($self->path)];
+    }
+
+    $self->{tags};
+}
+
 sub match {
     my ($self, $method, $path) = @_;
 
